<?php

namespace Asadi\Notific\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Notific\Interfaces\NotificRepositoryInterface;
use Asadi\Notific\Repositories\Presenter\NotificItemTransformer;

/**
 * Pubic API controller class.
 */
class NotificPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Notific\Interfaces\NotificRepositoryInterface $notific
     *
     * @return type
     */
    public function __construct(NotificRepositoryInterface $notific)
    {
        $this->repository = $notific;
        parent::__construct();
    }

    /**
     * Show notific's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $notifics = $this->repository
            ->setPresenter('\\Asadi\\Notific\\Repositories\\Presenter\\NotificListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $notifics['code'] = 2000;
        return response()->json($notifics)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show notific.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $notific = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($notific)) {
            $notific         = $this->itemPresenter($module, new NotificItemTransformer);
            $notific['code'] = 2001;
            return response()->json($notific)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
