<?php

namespace Asadi\Notific\Http\Controllers;
use Litepie\Notific\Http\Requests\NotificRequest;
use Litepie\Notific\Models\Notific;

trait NotificWorkflow {
	
    /**
     * Workflow controller function for notific.
     *
     * @param Model   $notific
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(NotificRequest $request, Notific $notific, $step)
    {

        try {

            $notific->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('notific::notific.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/notific/notific/' . $notific->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/notific/notific/' . $notific->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for notific.
     *
     * @param Model   $notific
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Notific $notific, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $notific->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('notific::notific.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('notific::admin.notific.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('notific::admin.notific.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('notific::admin.notific.message', $data)->render();

        }

    }
}