<?php

namespace Asadi\Notific\Policies;

use App\User;
use Asadi\Notific\Models\Notific;

class NotificPolicy
{

    /**
     * Determine if the given user can view the notific.
     *
     * @param User $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function view(User $user, Notific $notific)
    {
        if ($user->canDo('notific.notific.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $notific->user_id;
    }

    /**
     * Determine if the given user can create a notific.
     *
     * @param User $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('notific.notific.create');
    }

    /**
     * Determine if the given user can update the given notific.
     *
     * @param User $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function update(User $user, Notific $notific)
    {
        if ($user->canDo('notific.notific.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $notific->user_id;
    }

    /**
     * Determine if the given user can delete the given notific.
     *
     * @param User $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function destroy(User $user, Notific $notific)
    {
        if ($user->canDo('notific.notific.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $notific->user_id;
    }

    /**
     * Determine if the given user can verify the given notific.
     *
     * @param User $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function verify(User $user, Notific $notific)
    {
        if ($user->canDo('notific.notific.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('notific.notific.verify') 
        && $user->is('manager')
        && $notific->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given notific.
     *
     * @param User $user
     * @param Notific $notific
     *
     * @return bool
     */
    public function approve(User $user, Notific $notific)
    {
        if ($user->canDo('notific.notific.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
