<?php

namespace Asadi\Notific\Workflow;

use Asadi\Notific\Models\Notific;
use Validator;

class NotificValidator
{

    /**
     * Determine if the given notific is valid for complete status.
     *
     * @param Notific $notific
     *
     * @return bool / Validator
     */
    public function complete(Notific $notific)
    {
        return Validator::make($notific->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given notific is valid for verify status.
     *
     * @param Notific $notific
     *
     * @return bool / Validator
     */
    public function verify(Notific $notific)
    {
        return Validator::make($notific->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given notific is valid for approve status.
     *
     * @param Notific $notific
     *
     * @return bool / Validator
     */
    public function approve(Notific $notific)
    {
        return Validator::make($notific->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given notific is valid for publish status.
     *
     * @param Notific $notific
     *
     * @return bool / Validator
     */
    public function publish(Notific $notific)
    {
        return Validator::make($notific->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given notific is valid for archive status.
     *
     * @param Notific $notific
     *
     * @return bool / Validator
     */
    public function archive(Notific $notific)
    {
        return Validator::make($notific->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given notific is valid for unpublish status.
     *
     * @param Notific $notific
     *
     * @return bool / Validator
     */
    public function unpublish(Notific $notific)
    {
        return Validator::make($notific->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
